# # Plots

# ### Imports

# +
import numpy as np

import matplotlib
import matplotlib.pyplot as plt
from matplotlib import rc

matplotlib.use("pgf")
matplotlib.rcParams.update(
    {
        "pgf.texsystem": "xelatex",
        "font.family": "serif",
        "text.usetex": True,
        "pgf.rcfonts": False,
    }
)

from functools import partial
from modules import infinite_system, utils, system, utils, pauli, functions
import numpy as np
import kwant
import tqdm

import matplotlib as mpl
import os
import xarray as xr

# -

# ### Armchair vs. zigzag

# +
# %matplotlib widget

fig, axs = plt.subplots(
    2, 2, gridspec_kw={"hspace": 0.4, "wspace": 0.15}, sharey="row", figsize=(8, 12)
)
axs = np.reshape(axs, -1)
ax1, ax2, ax3, ax4 = axs

rc("font", **{"family": "sans-serif", "sans-serif": ["Helvetica"]})
rc("text", usetex=True)
plt.rcParams["lines.linewidth"] = 0.654
plt.rcParams["font.size"] = 18
plt.rcParams["legend.fontsize"] = 18

# Extract data
dataset_bands_armchair = xr.open_dataset("./files/bands/armchair/dataset_armchair.nc")
dataset_bands_zigzag = xr.open_dataset("./files/bands/zigzag/dataset_zigzag.nc")
dataset_GNS_armchair = xr.open_dataset(
    "./files/transport/spinless/square_sc/data/GNS_mu_B_square_armchair.nc"
)
dataset_GNS_zigzag = xr.open_dataset(
    "./files/transport/spinless/square_sc/data/GNS_mu_B_square_zigzag.nc"
)

# Band plots
utils.plot_bands(dataset_bands_armchair, ax=ax1)

utils.plot_bands(dataset=dataset_bands_zigzag, ax=ax2, show_y_label=False)

# Conductance plots
utils.plot_GNS(dataset_GNS_armchair, fig=fig, ax=ax3, show_clb=False, set_fonts=False)

im = utils.plot_GNS(
    dataset_GNS_zigzag,
    fig=fig,
    ax=ax4,
    show_y_label=False,
    show_clb=False,
    set_fonts=False,
)

# Add colorbars
clb = fig.colorbar(
    im, ax=axs.ravel().tolist(), orientation="horizontal", shrink=0.75, aspect=30
)
clb.set_label(r"$G_{xx}\ \left[ \frac{e^2}{h} \right]$", labelpad=0)
clb.set_ticks([-2, -1, 0, 1, 2])

# Add labels
ax1.text(0.0, 1.05, r"$(a)$", transform=ax1.transAxes)
ax2.text(0.0, 1.05, r"$(b)$", transform=ax2.transAxes)
ax3.text(0.0, 0.9, r"$(c)$", c="w", transform=ax3.transAxes)
ax4.text(0.0, 0.9, r"$(d)$", c="w", transform=ax4.transAxes)

# Set titles
ax1.set_title(r"$\mathrm{armchair}$")
ax2.set_title(r"$\mathrm{zigzag}$")

# Save and show
plt.savefig("./plots/fig1.pdf", bbox_inches="tight")
fig.show()
# -


