# # Plots

# ### Imports

# +
import numpy as np

import matplotlib
import matplotlib.pyplot as plt
from matplotlib import rc

matplotlib.use("pgf")
matplotlib.rcParams.update(
    {
        "pgf.texsystem": "xelatex",
        "font.family": "serif",
        "text.usetex": True,
        "pgf.rcfonts": False,
    }
)

from functools import partial
from modules import infinite_system, utils, system, utils, pauli, functions
import numpy as np
import kwant
import tqdm

import matplotlib as mpl
import os
import xarray as xr

# -

# ### Fermi mismatch

# +
# %matplotlib widget
import matplotlib.pylab as pl
import matplotlib.gridspec as gridspec

# Create 2x2 sub plots
gs = gridspec.GridSpec(1, 2, wspace=0.35, hspace=1.0)

plt.rcParams["font.size"] = 18
plt.rcParams["legend.fontsize"] = 18
plt.rcParams["lines.linewidth"] = 1.0

fig = plt.figure(figsize=(9, 3))
ax1 = fig.add_subplot(gs[0, 0])
ax2 = fig.add_subplot(gs[0, 1])

# Extract data
dataset_bands = xr.open_dataset(
    "./files/bands/fermi_mismatch/dataset_fermi_mismatch.nc"
)
dataset_GNS = xr.open_dataset(
    "./files/transport/spinless/honeycomb_sc/data/GNS_mu_B_high_fermi_mismatch.nc"
)

utils.plot_bands(dataset=dataset_bands, ax=ax1, show_y_label=True)

ax1.text(0.0, 1.05, r"$(a)$", transform=ax1.transAxes)

utils.plot_GNS(
    dataset=dataset_GNS,
    fig=fig,
    ax=ax2,
    show_clb=True,
    show_y_label=True,
    set_fonts=False,
)

ax2.text(0.0, 1.05, r"$(b)$", c="k", transform=ax2.transAxes)

plt.tight_layout()
fig.savefig("./plots/fig2.pdf", bbox_inches="tight")
fig.show()
# -


